import 'dart:convert';
import 'dart:ui';

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter/rendering.dart';
import 'package:flutter/widgets.dart';
import 'package:http/http.dart' as http;
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/list_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';

import 'home_screen.dart';

late UserBean userBean;
late bool isGetCountryList;

class AppRegistrationScreen extends StatefulWidget {
  AppRegistrationScreen(UserBean bean, bool b) {
    userBean = bean;
    isGetCountryList = b;
  }

  @override
  _AppRegistrationScreenState createState() => _AppRegistrationScreenState();
}

class _AppRegistrationScreenState extends State<AppRegistrationScreen> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    if (isGetCountryList) {
      CommonUtils.GetCountryListData(context).then((value) => {getCountryId()});
    } else
      registration();
  }

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      color: Colors.white,
      home: Scaffold(
        body: Container(
          color: Colors.white,
          child: Column(
            children: [
              Expanded(
                flex: 1,
                child: Align(
                  alignment: Alignment.bottomCenter,
                  child: InkWell(
                    onTap: () async {},
                    child: Image.network(
                      'https://royalty.shareapps.net/img/green-icon.png',
                      width: 50,
                      height: 50,
                    ),
                  ),
                ),
              ),
              AddSizeBox(100, 0),
              const Expanded(
                flex: 1,
                child: Text(
                  StringUtils.REGISTRATION_WAIT_MESSAGE,
                  textAlign: TextAlign.center,
                  style: TextStyle(
                      decoration: TextDecoration.none,
                      fontSize: 15,
                      color: Colors.black),
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Future<dynamic> appRegistration(Uri url, String body) async {
    return http
        .post(url, body: body, headers: StringUtils.GetApiHeaders())
        .then((http.Response response) {
      Map<String, dynamic> map = json.decode(response.body);
      final int statusCode = response.statusCode;
      if (statusCode < 200 || statusCode > 400 || json == null) {
        // CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.red);
        Navigator.pop(context);
        throw new Exception("Error while fetching data");
      }
      return map;
    });
  }

  Future<void> registration() async {
    var body = json.encode({
      StringUtils.OS: CommonUtils.getPlatform(),
      StringUtils.DEVICE_ID: userBean.deviceId,
      StringUtils.EMAIL_PARAM: userBean.email,
      StringUtils.PHONE_NUMBER_PARAM: userBean.phone,
      StringUtils.COUNTRY_ID: userBean.country_id,
      "first_name": userBean.first_name,
      "last_name": userBean.last_name
    });

    Map<String, dynamic> map =
        await appRegistration(Uri.parse(StringUtils.API_REGISTRATION), body);
    StringUtils.setToken(map[StringUtils.TOKEN].toString());
    if (map[StringUtils.STATUS].toString().compareTo(StringUtils.SUCCESS) !=
        null) {
      Navigator.pushReplacement(context,
          MaterialPageRoute(builder: (context) => HomeScreen(userBean)));
    } else {
      // CommonUtils.showToast(map[StringUtils.MESSAGE], Colors.green);
      Navigator.pop(context);
    }
  }

  getCountryId() {
    userBean.country_id = ListUtil.countryList
        .firstWhere((element) =>
            element.cncode.toString().compareTo(userBean.country_id) == 0)
        .id
        .toString();

    registration();
  }
}
