import 'dart:convert';
import 'dart:io';

import 'package:dropdown_search/dropdown_search.dart';
import 'package:flutter/material.dart';
import 'package:platform_device_id_v3/platform_device_id.dart';
// import 'package:searchable_dropdown/searchable_dropdown.dart';
import 'package:share_apps/model/country_bean.dart';
import 'package:share_apps/model/user_bean.dart';
import 'package:share_apps/utils/common_utils.dart';
import 'package:share_apps/utils/list_utils.dart';
import 'package:share_apps/utils/string_utils.dart';
import 'package:share_apps/widgets/widgets_importer.dart';
import 'package:shared_preferences/shared_preferences.dart';
import 'app_registration_screen.dart';

final FocusNode _firstNameFocus = FocusNode();
final FocusNode _lastNameFocus = FocusNode();
final FocusNode _emailAddressFocus = FocusNode();
final FocusNode _phoneNumberFocus = FocusNode();
final _formKey = GlobalKey<FormState>();

late TextEditingController firstNameController;
late TextEditingController lastNameController;
late TextEditingController emailController;
late TextEditingController numberController;

late UserBean _userBean;

class InvitationForm extends StatefulWidget {
  InvitationForm(UserBean bean) {
    _userBean = bean;
    firstNameController = TextEditingController(text: _userBean.first_name);
    lastNameController = TextEditingController(text: _userBean.last_name);
    emailController = TextEditingController(text: _userBean.email);
    numberController = TextEditingController(text: _userBean.phone);
  }

  @override
  _InvitationFormState createState() => _InvitationFormState();
}

late String _deviceId;

class _InvitationFormState extends State<InvitationForm> {
  @override
  void initState() {
    // TODO: implement initState
    super.initState();
    initDeviceId();
    for (int i = 0; i < ListUtil.language_list.length; i++) {
      languageItems.add(
          // DropdownMenuItem(
          //   child: Text(ListUtil.language_list[i]),
          //   value: ListUtil.language_list[i],
          // ),
          ListUtil.language_list[i]);
    }
    CommonUtils.GetCountryListData(context)
        .then((value) => {addDropDownData()});
  }

  List<String> languageItems = [];
  List<String> countryItems = [];

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      debugShowCheckedModeBanner: false,
      home: Scaffold(
        backgroundColor: Colors.white,
        body: SingleChildScrollView(
          child: Container(
            margin: EdgeInsets.all(20),
            color: Colors.white,
            child: Form(
              key: _formKey,
              child: Column(
                crossAxisAlignment: CrossAxisAlignment.start,
                children: [
                  AddSizeBox(50, 0),
                  //------------------
                  AddText(StringUtils.FIRST_NAME, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.text,
                      TextInputAction.next,
                      StringUtils.FIRST_NAME,
                      _firstNameFocus,
                      _lastNameFocus,
                      firstNameController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.LAST_NAME, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.text,
                      TextInputAction.next,
                      StringUtils.LAST_NAME,
                      _lastNameFocus,
                      _emailAddressFocus,
                      lastNameController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.EMAIL, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.emailAddress,
                      TextInputAction.next,
                      StringUtils.EMAIL,
                      _emailAddressFocus,
                      _phoneNumberFocus,
                      emailController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.COUNTRY, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  // SetLangaugeCountryData(true),
                  // SearchableDropdown.single(
                  //   displayClearIcon: false,
                  //   items: countryItems,
                  //   value: _selectedCountry,
                  //   hint: "Select Country",
                  //   searchHint: "Select Country",
                  //   onChanged: (value) {
                  //     setState(() {
                  //       _selectedCountry = value;
                  //     });
                  //   },
                  //   isExpanded: true,
                  // ),
                  DropdownSearch<String>(
                    popupProps: const PopupProps.menu(
                      showSelectedItems: true,
                      // disabledItemFn: (String s) => s.startsWith('I'),
                    ),
                    items: countryItems,
                    dropdownDecoratorProps: const DropDownDecoratorProps(
                      dropdownSearchDecoration: InputDecoration(
                        labelText: "Select Country",
                        hintText: "Select Country",
                      ),
                    ),
                    onChanged: (value) {
                      setState(() {
                        if (value != null) {
                          _selectedCountry = value;
                        }
                      });
                    },
                    selectedItem: _selectedCountry,
                  ),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.PHONE_NUMBER, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  AddTextField(
                      context,
                      TextInputType.number,
                      TextInputAction.done,
                      StringUtils.PHONE_NUMBER,
                      _phoneNumberFocus,
                      _phoneNumberFocus,
                      numberController),
                  //------------------
                  AddSizeBox(15, 0),
                  AddText(StringUtils.LANGUAGE, Colors.black, 15.0,
                      FontWeight.bold, false),
                  AddSizeBox(15, 0),
                  // SetLangaugeCountryData(false),
                  // SearchableDropdown.single(
                  //   displayClearIcon: false,
                  //   items: languageItems,
                  //   value: _selectedLanguage,
                  //   hint: "Select Language",
                  //   searchHint: "Select Language",
                  //   onChanged: (value) {
                  //     setState(() {
                  //       _selectedLanguage = value;
                  //     });
                  //   },
                  //   isExpanded: true,
                  // ),
                  DropdownSearch<String>(
                    popupProps: const PopupProps.menu(
                      showSelectedItems: true,
                      // disabledItemFn: (String s) => s.startsWith('I'),
                    ),
                    items: languageItems,
                    dropdownDecoratorProps: const DropDownDecoratorProps(
                      dropdownSearchDecoration: InputDecoration(
                        labelText: "Select Language",
                        hintText: "Select Language",
                      ),
                    ),
                    onChanged: (value) {
                      setState(() {
                        if (value != null) {
                          _selectedLanguage = value;
                        }
                      });
                    },
                    selectedItem: _selectedLanguage,
                  ),
                  //------------------
                  AddSizeBox(50, 0),
                  Row(
                    mainAxisAlignment: MainAxisAlignment.center,
                    children: [BottomButton(true), BottomButton(false)],
                  ),
                ],
              ),
            ),
          ),
        ),
      ),
    );
  }

  Widget BottomButton(bool isExit) {
    return Expanded(
      flex: 1,
      child: InkWell(
        onTap: () {
          if (isExit) {
            Navigator.pop(context);
          } else {
            if (_formKey.currentState!.validate()) {
              if (_selectedCountry == '') {
                CommonUtils.showToast('Selected Country', Colors.red);
              } else if (numberController.text.length < 5) {
                CommonUtils.showToast(StringUtils.ERROR_NUMBER, Colors.red);
              } else if (_selectedLanguage == '') {
                CommonUtils.showToast('Selected Language', Colors.red);
              } else {
                print("----- idd :- " +
                    ListUtil.countryList
                        .firstWhere((element) =>
                            element.name
                                .toString()
                                .compareTo(_selectedCountry) ==
                            0)
                        .id
                        .toString());

                UserBean bean = UserBean(
                    firstNameController.text,
                    lastNameController.text,
                    emailController.text,
                    getNumber(),
                    // (ListUtil.country_list.indexOf(_selectedCountry)).toString(),
                    ListUtil.countryList
                        .firstWhere((element) =>
                            element.name
                                .toString()
                                .compareTo(_selectedCountry) ==
                            0)
                        .id
                        .toString(),
                    _selectedLanguage,
                    _deviceId);
                saveUserData(StringUtils.USER_DATA, bean);
              }
            }
          }
        },
        child: Container(
          margin: EdgeInsets.all(5),
          color: isExit ? Colors.amberAccent : Colors.green,
          child: Padding(
            padding: const EdgeInsets.all(15.0),
            child: AddText(isExit ? StringUtils.EXIT : StringUtils.PROCEED,
                Colors.white, 18.0, FontWeight.bold, false),
          ),
        ),
      ),
    );
  }

  var _selectedLanguage =
      (_userBean.language != null && _userBean.language.length > 0)
          ? _userBean.language
          : "";
  var _selectedCountry = "";

  Future<void> initDeviceId() async {
    _deviceId = await PlatformDeviceId.getDeviceId ?? '';
    if (!mounted) return;
  }

  Future<void> openNextScreen(UserBean bean) async {
    try {
      final result = await InternetAddress.lookup('google.com');
      if (result.isNotEmpty && result[0].rawAddress.isNotEmpty) {
        Route route = MaterialPageRoute(
            builder: (context) => AppRegistrationScreen(bean, false));
        Navigator.pushReplacement(context, route);
      }
    } on SocketException catch (_) {
      CommonUtils.showToast(StringUtils.CHECK_NETWORK, Colors.red);
    }
  }

  void saveUserData(String key, UserBean bean) async {
    final prefs = await SharedPreferences.getInstance();
    prefs.setString(key, jsonEncode(bean.toJson()));
    openNextScreen(bean);
  }

  String getNumber() {
    String number = numberController.text;
    if (!number.contains("+")) {
      number = ListUtil.countryList
              .firstWhere((element) =>
                  element.id.toString().compareTo(_userBean.country_id) == 0)
              .callCode
              .toString() +
          number;
    }
    return number;
  }

  void addDropDownData() {
    ListUtil.countryList.forEach((CountryBean element) {
      countryItems.add(
        // DropdownMenuItem(
        //   value: element.name,
        //   child: Text(element.name!),
        // ),
        element.name!,
      );
      if ((_userBean.country_id != null && _userBean.country_id.length > 0)) {
        // print("----- Is Match :- " + _userBean.country_id);
        if (element.cncode.toString().compareTo(_userBean.country_id) == 0) {
          _selectedCountry = element.name!;
        }
      }
    });
    setState(() {});
  }
}
